=======
History
=======

0.8.2 (2021-04-20)
==================

* sscweb trajectories are always in km

0.8.1 (2021-04-18)
==================

* Fixes minimum request duration for sscweb

0.8.0 (2021-04-18)
==================

* Full support for trajectories and 0.2 proxy version

0.7.2 (2020-11-13)
==================

* ccsweb/proxy: Fix missing coordinate system parameter

0.7.1 (2020-11-13)
==================

* Fix project URL on PyPi

0.7.0 (2020-11-13)
==================

* SSCWEB support to get satellites trajectories.
* Few bug fixes.
* Totally disabled cdf support for now.

0.1.0 (2019-12-07)
==================

* First release on PyPI.
